@@ -96,8 +96,8 @@ class _BaseGraphSingleGenerator(Dataset):
     def __init__(
             self,
             dataset_size: int,
-            targets: Union[np.ndarray,torch.Tensor],
-            sample_weights: [np.ndarray,torch.Tensor] = None,
+            targets: Union[np.ndarray, torch.Tensor],
+            sample_weights: [np.ndarray, torch.Tensor] = None,
     ):
         """
         Args:
@@ -108,7 +108,7 @@ class _BaseGraphSingleGenerator(Dataset):
 
         if targets is not None:
             if isinstance(targets, np.ndarray):
-                self.targets = torch.from_numpy(targets).resize((dataset_size, -1))
+                self.targets = torch.from_numpy(targets.reshape(dataset_size, -1))
             else:
                 self.targets = targets
         else:
@@ -116,7 +116,7 @@ class _BaseGraphSingleGenerator(Dataset):
 
         if sample_weights is not None:
             if isinstance(sample_weights, np.ndarray):
-                self.sample_weights = torch.from_numpy(sample_weights).resize((dataset_size, -1))
+                self.sample_weights = torch.from_numpy(targets.reshape(sample_weights, -1))
             else:
                 self.sample_weights = sample_weights
         else:
@@ -348,7 +348,7 @@ class DuplicateGraphGenerator(_BaseGraphSingleGenerator):
             sample_weights: np.ndarray = None,
             duplicate: int = 5,
             noise: float = 0,
-            shuffle: bool = 0,
+            shuffle: bool = False,
             random_state: bool = 0,
             print_data_size=True,
     ):
