@@ -13,6 +13,7 @@ from featurebox.featurizers.generator import MGEDataLoader
 
 
 def class_eval(prediction, target):
+    """Classification."""
     prediction = np.exp(prediction.numpy())
     target = target.numpy()
     pred_label = np.argmax(prediction, axis=1)
@@ -149,7 +150,7 @@ class BaseLearning:
                 self.loss_method = torch.nn.CrossEntropyLoss()
             elif self.clf == "multi_label":
                 self.loss_method = torch.nn.L1Loss()
-                # 主要是用来判定实际的输出与期望的输出的接近程度 MAE: 1/N |y_pred-y|
+                # 主要是用来判定实际的输出与期望的输出的接近程度 MAE: 1/N |y_pred-y| y 为多列
             else:
                 self.loss_method = torch.nn.MSELoss()
 
@@ -162,6 +163,7 @@ class BaseLearning:
         self.threshold = loss_threshold
         # *.pth.tar or str
         self.run_train = self.run
+        self.fit = self.run_train
         self.print_what = print_what
         self.forward_hook_list = []
 
@@ -249,15 +251,18 @@ class BaseLearning:
             self.optimizer.zero_grad()
 
             y_pred = self.model(*batch_x)
-
-            lossi = self.loss_method(y_pred, batch_y)
-
+            try:
+                lossi = self.loss_method(y_pred, batch_y)
+            except TypeError:
+                target = batch_y.sign()
+                lossi = self.loss_method(y_pred, batch_y, target)
             losses.update(float(lossi.cpu().item()), batch_y.size(0))
 
             if self.clf is False:
                 mae_error = mae(y_pred.data.cpu(), batch_y.cpu())
                 mae_errors.update(mae_error, batch_y.size(0))
             else:
+
                 accuracy, precision, recall, fscore, auc_score = \
                     class_eval(y_pred.data.cpu(), batch_y.cpu())
 
@@ -316,7 +321,11 @@ class BaseLearning:
         for m, (batch_x, batch_y) in enumerate(self.test_loader):
 
             y_pred = self.model(*batch_x)
-            lossi = self.loss_method(y_pred, batch_y)
+            try:
+                lossi = self.loss_method(y_pred, batch_y)
+            except TypeError:
+                target = batch_y.sign()
+                lossi = self.loss_method(y_pred, batch_y, target)
 
             losses.update(lossi.cpu().item(), batch_y.size(0))
             if self.clf is False:
@@ -358,7 +367,7 @@ class BaseLearning:
         else:
             return auc_scores.avg
 
-    def score(self, predict_loader):
+    def mae_score(self, predict_loader):
         """Return MAE score."""
         y_pre, y_true = self.predict(predict_loader, return_y_true=True, add_hook=False)
         return float(mae(y_pre, y_true))
@@ -392,17 +401,24 @@ class BaseLearning:
         self.model.eval()
 
         ############
+
         handles = []
         if add_hook:
-            self.forward_hook_list = []
+            try:
+                self.forward_hook_list = []
 
-            def for_hook(module, input, output):
-                self.forward_hook_list.append(output)
+                def for_hook(module, input, output):
+                    self.forward_hook_list.append(output.detach().cpu())
 
-            le = len(self.model.fcs)
-            for i in range(le):
-                handles.append(self.model.fcs[1].register_forward_hook(for_hook))  # hook the fcs[i]
+                handles.append(self.model.conv_to_fc_softplus.register_forward_hook(for_hook))
 
+                le = len(self.model.softpluses)
+                for i in range(le):
+                    handles.append(self.model.softpluses[i].register_forward_hook(for_hook))  # hook the fcs[i]
+            except BaseException as e:
+                print(e)
+                raise AttributeError("The model must contain sub (model or layer) named ``conv_to_fc_softplus``and "
+                                     "nn.ModuleList named ``softpluses``")
         y_preds = []
         y_true = []
         batch_y = []
